==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/INativeUIElementBridge_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Type, markType } from "./type";
import { INativeUIElementFactory_$type } from "./INativeUIElementFactory";
import { List$1 } from "./List$1";
import { NativeUI } from "./NativeUI";
/**
 * @hidden
 */
export var INativeUIElementBridge_$type = /*@__PURE__*/ new Type(null, 'INativeUIElementBridge');
/**
 * @hidden
 */
var NativeUIComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIComponent, _super);
    function NativeUIComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.v = null;
        _this.b = null;
        _this.u = null;
        return _this;
    }
    NativeUIComponent.prototype.get_c = function () {
        return 8;
    };
    Object.defineProperty(NativeUIComponent.prototype, "c", {
        get: function () {
            return this.get_c();
        },
        enumerable: false,
        configurable: true
    });
    NativeUIComponent.y = function (a) {
        if (!NativeUIComponent.f.contains(a)) {
            NativeUIComponent.f.add(a);
        }
    };
    NativeUIComponent.z = function (a, b, c) {
        for (var d = 0; d < NativeUIComponent.f.count; d++) {
            if (NativeUIComponent.f._inner[d].supportsComponent(b)) {
                NativeUIComponent.f._inner[d].createComponent(a, b, c);
                break;
            }
        }
    };
    NativeUIComponent.aa = function (a, b, c) {
        for (var d = 0; d < NativeUIComponent.f.count; d++) {
            if (NativeUIComponent.f._inner[d].supportsComponent(b)) {
                NativeUIComponent.f._inner[d].createComponentSync(a, b, c);
                break;
            }
        }
    };
    NativeUIComponent.prototype.t = function (a) {
        return this.u;
    };
    NativeUIComponent.prototype.q = function (a) {
        var b = this.t(a);
        return NativeUI.j(a, b);
    };
    NativeUIComponent.prototype.af = function (a, b) {
        var c = this.t(a);
        NativeUI.ac(a, c, b);
    };
    NativeUIComponent.prototype.o = function (a) {
        var b = this.s(a);
        return this.p(b, a);
    };
    NativeUIComponent.prototype.ad = function (a, b) {
        var c = this.s(a);
        this.ae(c, a, b);
    };
    NativeUIComponent.prototype.w = function (a, b) {
        var c = this.r(a);
        this.x(c, this, a, b);
    };
    NativeUIComponent.prototype.x = function (a, b, c, d) {
        this.b.addHandler(a, b, c, d);
    };
    NativeUIComponent.prototype.ab = function (a, b) {
        var c = this.r(a);
        this.ac(c, this, a, b);
    };
    NativeUIComponent.prototype.ac = function (a, b, c, d) {
        this.b.removeHandler(a, b, c, d);
    };
    NativeUIComponent.prototype.p = function (a, b) {
        return this.b.getValue(a, b);
    };
    NativeUIComponent.prototype.ae = function (a, b, c) {
        this.b.setValue(a, b, c);
    };
    NativeUIComponent.prototype.s = function (a) {
        var b = this.u;
        b = this.b.getTargetForBuildInProperty(b, a);
        return b;
    };
    NativeUIComponent.prototype.r = function (a) {
        var b = this.u;
        b = this.b.getTargetForBuildInEvent(b, a);
        return b;
    };
    Object.defineProperty(NativeUIComponent.prototype, "n", {
        get: function () {
            return this.q(9);
        },
        set: function (a) {
            this.af(9, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "h", {
        get: function () {
            return this.q(10);
        },
        set: function (a) {
            this.af(10, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "j", {
        get: function () {
            return this.q(1);
        },
        set: function (a) {
            this.af(1, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ah", {
        get: function () {
            return this.q(2);
        },
        set: function (a) {
            this.af(2, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ai", {
        get: function () {
            return this.q(3);
        },
        set: function (a) {
            this.af(3, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ag", {
        get: function () {
            return this.q(5);
        },
        set: function (a) {
            this.af(5, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ao", {
        get: function () {
            return this.q(6);
        },
        set: function (a) {
            this.af(6, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "aj", {
        get: function () {
            return this.q(7);
        },
        set: function (a) {
            this.af(7, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "g", {
        get: function () {
            return this.q(8);
        },
        set: function (a) {
            this.af(8, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "i", {
        get: function () {
            return this.q(11);
        },
        set: function (a) {
            this.af(11, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "m", {
        get: function () {
            return this.q(12);
        },
        set: function (a) {
            this.af(12, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "an", {
        get: function () {
            return this.q(13);
        },
        set: function (a) {
            this.af(13, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "am", {
        get: function () {
            return this.q(14);
        },
        set: function (a) {
            this.af(14, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "al", {
        get: function () {
            return this.q(15);
        },
        set: function (a) {
            this.af(15, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ak", {
        get: function () {
            return this.q(16);
        },
        set: function (a) {
            this.af(16, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "l", {
        get: function () {
            return this.q(17);
        },
        set: function (a) {
            this.af(17, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "a", {
        get: function () {
            return this.q(18);
        },
        set: function (a) {
            this.af(18, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "k", {
        get: function () {
            return this.q(19);
        },
        set: function (a) {
            this.af(19, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "d", {
        get: function () {
            return this.b.getHorizontalAlignment(this.u);
        },
        set: function (a) {
            this.b.setHorizontalAlignment(this.u, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "e", {
        get: function () {
            return this.b.getVerticalAlignment(this.u);
        },
        set: function (a) {
            this.b.setVerticalAlignment(this.u, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIComponent.$t = markType(NativeUIComponent, 'NativeUIComponent');
    NativeUIComponent.f = new List$1(INativeUIElementFactory_$type, 0);
    return NativeUIComponent;
}(Base));
export { NativeUIComponent };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/INativeUIElementBridge_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Type, markType } from "./type";
import { INativeUIElementFactory_$type } from "./INativeUIElementFactory";
import { List$1 } from "./List$1";
import { NativeUI } from "./NativeUI";
/**
 * @hidden
 */
export var INativeUIElementBridge_$type = /*@__PURE__*/ new Type(null, 'INativeUIElementBridge');
/**
 * @hidden
 */
var NativeUIComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIComponent, _super);
    function NativeUIComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.w = null;
        _this.b = null;
        _this.v = null;
        return _this;
    }
    NativeUIComponent.prototype.ap = function (a) {
        return this.b.getDesiredSize(this.u, a);
    };
    NativeUIComponent.prototype.get_c = function () {
        return 8;
    };
    Object.defineProperty(NativeUIComponent.prototype, "c", {
        get: function () {
            return this.get_c();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "u", {
        get: function () {
            return this.b.getMethodTarget(this.v);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIComponent.z = function (a) {
        if (!NativeUIComponent.f.contains(a)) {
            NativeUIComponent.f.add(a);
        }
    };
    NativeUIComponent.aa = function (a, b, c) {
        for (var d = 0; d < NativeUIComponent.f.count; d++) {
            if (NativeUIComponent.f._inner[d].supportsComponent(b)) {
                NativeUIComponent.f._inner[d].createComponent(a, b, c);
                break;
            }
        }
    };
    NativeUIComponent.ab = function (a, b, c) {
        var d = 0;
        var e = new Array(b.length);
        var _loop_1 = function (f) {
            var g = b[f];
            for (var h = 0; h < NativeUIComponent.f.count; h++) {
                if (NativeUIComponent.f._inner[h].supportsComponent(g)) {
                    var i = f;
                    NativeUIComponent.f._inner[h].createComponent(a, g, function (j) {
                        e[f] = j;
                        d++;
                        if (d == b.length) {
                            c(e);
                        }
                    });
                    break;
                }
            }
        };
        for (var f = 0; f < b.length; f++) {
            _loop_1(f);
        }
    };
    NativeUIComponent.ac = function (a, b, c) {
        for (var d = 0; d < NativeUIComponent.f.count; d++) {
            if (NativeUIComponent.f._inner[d].supportsComponent(b)) {
                NativeUIComponent.f._inner[d].createComponentSync(a, b, c);
                break;
            }
        }
    };
    NativeUIComponent.prototype.t = function (a) {
        return this.b.getTargetForProperty(a, this.v);
    };
    NativeUIComponent.prototype.q = function (a) {
        var b = this.t(a);
        return NativeUI.j(a, b);
    };
    NativeUIComponent.prototype.ah = function (a, b) {
        var c = this.t(a);
        NativeUI.ac(a, c, b);
    };
    NativeUIComponent.prototype.o = function (a) {
        var b = this.s(a);
        return this.p(b, a);
    };
    NativeUIComponent.prototype.af = function (a, b) {
        var c = this.s(a);
        this.ag(c, a, b);
    };
    NativeUIComponent.prototype.x = function (a, b) {
        var c = this.r(a);
        this.y(c, this, a, b);
    };
    NativeUIComponent.prototype.y = function (a, b, c, d) {
        this.b.addHandler(a, b, c, d);
    };
    NativeUIComponent.prototype.ad = function (a, b) {
        var c = this.r(a);
        this.ae(c, this, a, b);
    };
    NativeUIComponent.prototype.ae = function (a, b, c, d) {
        this.b.removeHandler(a, b, c, d);
    };
    NativeUIComponent.prototype.p = function (a, b) {
        return this.b.getValue(a, b);
    };
    NativeUIComponent.prototype.ag = function (a, b, c) {
        this.b.setValue(a, b, c);
    };
    NativeUIComponent.prototype.s = function (a) {
        var b = this.v;
        b = this.b.getTargetForBuildInProperty(b, a);
        return b;
    };
    NativeUIComponent.prototype.r = function (a) {
        var b = this.v;
        b = this.b.getTargetForBuildInEvent(b, a);
        return b;
    };
    Object.defineProperty(NativeUIComponent.prototype, "n", {
        get: function () {
            return this.q(9);
        },
        set: function (a) {
            this.ah(9, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "h", {
        get: function () {
            return this.q(10);
        },
        set: function (a) {
            this.ah(10, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "j", {
        get: function () {
            return this.q(1);
        },
        set: function (a) {
            this.ah(1, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "aj", {
        get: function () {
            return this.q(2);
        },
        set: function (a) {
            this.ah(2, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ak", {
        get: function () {
            return this.q(3);
        },
        set: function (a) {
            this.ah(3, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "aq", {
        get: function () {
            return this.q(4);
        },
        set: function (a) {
            this.ah(4, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ai", {
        get: function () {
            return this.q(5);
        },
        set: function (a) {
            this.ah(5, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "as", {
        get: function () {
            return this.q(6);
        },
        set: function (a) {
            this.ah(6, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "al", {
        get: function () {
            return this.q(7);
        },
        set: function (a) {
            this.ah(7, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "g", {
        get: function () {
            return this.q(8);
        },
        set: function (a) {
            this.ah(8, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "i", {
        get: function () {
            return this.q(11);
        },
        set: function (a) {
            this.ah(11, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "m", {
        get: function () {
            return this.q(12);
        },
        set: function (a) {
            this.ah(12, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ar", {
        get: function () {
            return this.q(13);
        },
        set: function (a) {
            this.ah(13, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "ao", {
        get: function () {
            return this.q(14);
        },
        set: function (a) {
            this.ah(14, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "an", {
        get: function () {
            return this.q(15);
        },
        set: function (a) {
            this.ah(15, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "am", {
        get: function () {
            return this.q(16);
        },
        set: function (a) {
            this.ah(16, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "l", {
        get: function () {
            return this.q(17);
        },
        set: function (a) {
            this.ah(17, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "a", {
        get: function () {
            return this.q(18);
        },
        set: function (a) {
            this.ah(18, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "k", {
        get: function () {
            return this.q(19);
        },
        set: function (a) {
            this.ah(19, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "d", {
        get: function () {
            return this.b.getHorizontalAlignment(this.v);
        },
        set: function (a) {
            this.b.setHorizontalAlignment(this.v, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIComponent.prototype, "e", {
        get: function () {
            return this.b.getVerticalAlignment(this.v);
        },
        set: function (a) {
            this.b.setVerticalAlignment(this.v, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIComponent.$t = markType(NativeUIComponent, 'NativeUIComponent');
    NativeUIComponent.f = new List$1(INativeUIElementFactory_$type, 0);
    return NativeUIComponent;
}(Base));
export { NativeUIComponent };
